pub trait TreeProps {
// Required methods
fn parent(&self) -> Entity;
fn first_child(&self) -> Entity;
fn parent_window(&self) -> Entity;
}Expand description
Trait for querying properties of the tree from a context.
Required Methods
Sourcefn first_child(&self) -> Entity
fn first_child(&self) -> Entity
Returns the entity id of the first_child of the current view.
Sourcefn parent_window(&self) -> Entity
fn parent_window(&self) -> Entity
Returns the entity id of the parent window of the current view.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".